@@ -124,8 +124,9 @@ if __name__ == '__main__':
 
 	if options.instrument != None:
 		if options.instrument in get_available_instruments():
-			block.instruments = [getattr(Musicians, \
-					options.instrument)({})]
+			i = getattr(Musicians, options.instrument)
+			i = i({'channel': 1, 'start': 0})
+			block.instruments = [i]
 		else:
 			if options.verbose:
 				print "Unknown instrument:", options.instrument
